@@ -54,12 +54,47 @@ class Context(BaseModel):
 
 
 class MCPServerConfig(BaseModel):
-    model_config = ConfigDict(extra="ignore")
+    """
+    Configuration for an MCP server.
 
-    command: str
-    args: Optional[list[str]]
-    env: Optional[dict[str, Any]] = None
-    auth_token: Optional[str] = None
+    Defines how to start and connect to an MCP server instance, including
+    command, arguments, environment variables, and authentication parameters.
+
+    Attributes:
+        command (str): The command used to invoke the MCP server
+        args (Optional[list[str]]): List of arguments for the server command
+        env (Optional[dict[str, Any]]): Environment variables for the server process
+        auth_token (Optional[str]): Authentication token for MCP-Connect server
+    """
+
+    command: Optional[str] = Field(
+        None,
+        description="The command used to invoke the MCP server (e.g., 'npx', 'uvx') using a stdio transport",
+    )
+    url: Optional[str] = Field(
+        None,
+        description="The HTTP URL of a remote MCP server (use when connecting over HTTP/streamable-http).",
+    )
+    args: Optional[list[str]] = Field(
+        default_factory=list,
+        description="List of arguments to pass to the MCP server command",
+    )
+    headers: Optional[dict[str, str]] = Field(
+        default_factory=dict,
+        description="HTTP headers to include when connecting to an MCP server via `url`.",
+    )
+    env: Optional[dict[str, Any]] = Field(
+        default_factory=dict,
+        description="Environment variables to be set for the MCP server process",
+    )
+    type: Optional[str] = Field(
+        None,
+        description="Transport type. Set to 'streamable-http' to use a streamable HTTP transport; "
+        "leave null for stdio/sse command transports.",
+    )
+    auth_token: Optional[str] = Field(
+        None, description="Authentication token for the MCP-Connect server"
+    )
 
 
 class MCPServerDetails(BaseModel):
@@ -112,7 +147,10 @@ class Assistant(AssistantBase):
     project: str
     llm_model_type: Optional[str] = None
     toolkits: List[ToolKitDetails] = Field(default_factory=list)
-    user_prompts: List[str] = Field(default_factory=list)
+    conversation_starters: List[str] = Field(
+        default_factory=list,
+        description="List of suggested conversation starter prompts",
+    )
     shared: bool = False
     is_react: bool = False
     is_global: bool = False
@@ -141,7 +179,10 @@ class AssistantRequestBase(AssistantBase):
     context: List[Context] = Field(default_factory=list)
     llm_model_type: str
     toolkits: List[ToolKitDetails] = Field(default_factory=list)
-    user_prompts: List[str] = Field(default_factory=list)
+    conversation_starters: List[str] = Field(
+        default_factory=list,
+        description="List of suggested conversation starter prompts",
+    )
     shared: bool = False
     is_react: bool = False
     is_global: Optional[bool] = False
@@ -208,7 +249,9 @@ class AssistantChatRequest(BaseModel):
     )
     text: str = Field(description="User's input")
     content_raw: Optional[str] = Field(default="", description="Raw content input")
-    file_name: Optional[str] = Field(default=None, description="Associated file name")
+    file_names: List[str] = Field(
+        default_factory=list, description="List of file names"
+    )
     llm_model: Optional[str] = Field(
         default=None, description="Specific LLM model to use"
     )
@@ -232,6 +275,13 @@ class AssistantChatRequest(BaseModel):
         description="Structured output schema for the agent. \
             If specified, `generated` field in response will have the same type",
     )
+    mcp_server_single_usage: Optional[bool] = Field(
+        default=None,
+        description="Override conversation-level MCP server lifecycle setting for this request. \
+            When true, MCP servers are created fresh and destroyed after use. \
+            When false, MCP servers are cached and reused. \
+            If not specified, uses conversation's default setting.",
+    )
 
 
 class BaseModelResponse(BaseModel):
